summaryrefslogtreecommitdiff
path: root/src/lib
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2025-10-15 00:05:22 +0200
committerCarl Hetherington <cth@carlh.net>2026-02-16 01:20:17 +0100
commite23af8c3cf898dd443de7e081542f039f6763cec (patch)
tree0d60cea326866b4f39a55fd7af00bb079cebac3c /src/lib
parent144590d21b70f0239612b82f7c1d422533c64fbb (diff)
Rename ContentStore -> ShowPlaylistContentStore.
Diffstat (limited to 'src/lib')
-rw-r--r--src/lib/show_playlist_content_store.cc (renamed from src/lib/content_store.cc)16
-rw-r--r--src/lib/show_playlist_content_store.h (renamed from src/lib/content_store.h)10
-rw-r--r--src/lib/spl.cc4
-rw-r--r--src/lib/spl.h4
-rw-r--r--src/lib/wscript2
5 files changed, 18 insertions, 18 deletions
diff --git a/src/lib/content_store.cc b/src/lib/show_playlist_content_store.cc
index 35fde3c8e..97a53bb74 100644
--- a/src/lib/content_store.cc
+++ b/src/lib/show_playlist_content_store.cc
@@ -21,11 +21,11 @@
#include "config.h"
#include "content_factory.h"
-#include "content_store.h"
#include "cross.h"
#include "dcp_content.h"
#include "examine_content_job.h"
#include "job_manager.h"
+#include "show_playlist_content_store.h"
#include "util.h"
#include <dcp/cpl.h>
#include <dcp/exceptions.h>
@@ -41,11 +41,11 @@ using std::string;
using std::vector;
-ContentStore* ContentStore::_instance = nullptr;
+ShowPlaylistContentStore* ShowPlaylistContentStore::_instance = nullptr;
vector<pair<string, string>>
-ContentStore::update(std::function<bool()> pulse)
+ShowPlaylistContentStore::update(std::function<bool()> pulse)
{
_content.clear();
auto dir = Config::instance()->player_content_directory();
@@ -116,7 +116,7 @@ ContentStore::update(std::function<bool()> pulse)
shared_ptr<Content>
-ContentStore::get_by_digest(string digest) const
+ShowPlaylistContentStore::get_by_digest(string digest) const
{
auto iter = std::find_if(_content.begin(), _content.end(), [digest](shared_ptr<const Content> content) {
return content->digest() == digest;
@@ -131,7 +131,7 @@ ContentStore::get_by_digest(string digest) const
shared_ptr<Content>
-ContentStore::get_by_cpl_id(string id) const
+ShowPlaylistContentStore::get_by_cpl_id(string id) const
{
auto iter = std::find_if(_content.begin(), _content.end(), [id](shared_ptr<const Content> content) {
if (auto dcp = dynamic_pointer_cast<const DCPContent>(content)) {
@@ -152,11 +152,11 @@ ContentStore::get_by_cpl_id(string id) const
}
-ContentStore*
-ContentStore::instance()
+ShowPlaylistContentStore*
+ShowPlaylistContentStore::instance()
{
if (!_instance) {
- _instance = new ContentStore();
+ _instance = new ShowPlaylistContentStore();
}
return _instance;
diff --git a/src/lib/spl.cc b/src/lib/spl.cc
index 652efe5b8..e958bf7c9 100644
--- a/src/lib/spl.cc
+++ b/src/lib/spl.cc
@@ -19,7 +19,7 @@
*/
-#include "content_store.h"
+#include "show_playlist_content_store.h"
#include "spl.h"
#include <libcxml/cxml.h>
#include <dcp/filesystem.h>
@@ -36,7 +36,7 @@ using std::shared_ptr;
void
-SPL::read (boost::filesystem::path path, ContentStore* store)
+SPL::read(boost::filesystem::path path, ShowPlaylistContentStore* store)
{
_spl.clear ();
_missing = false;
diff --git a/src/lib/spl.h b/src/lib/spl.h
index a02885c87..9d1a9fdbc 100644
--- a/src/lib/spl.h
+++ b/src/lib/spl.h
@@ -31,7 +31,7 @@ LIBDCP_ENABLE_WARNINGS
#include <algorithm>
-class ContentStore;
+class ShowPlaylistContentStore;
class SPL
@@ -70,7 +70,7 @@ public:
std::iter_swap(_spl.begin() + a, _spl.begin() + b);
}
- void read(boost::filesystem::path path, ContentStore* store);
+ void read(boost::filesystem::path path, ShowPlaylistContentStore* store);
void write(boost::filesystem::path path) const;
std::string id() const {
diff --git a/src/lib/wscript b/src/lib/wscript
index a6130e41c..3489aab7b 100644
--- a/src/lib/wscript
+++ b/src/lib/wscript
@@ -57,7 +57,6 @@ sources = """
config.cc
content.cc
content_factory.cc
- content_store.cc
combine_dcp_job.cc
copy_dcp_details_to_film.cc
cover_sheet.cc
@@ -195,6 +194,7 @@ sources = """
send_notification_email_job.cc
send_problem_report_job.cc
server.cc
+ show_playlist_content_store.cc
shuffler.cc
state.cc
spl.cc
diff --git a/src/lib/content_store.h b/src/lib/show_playlist_content_store.h
index 1b3afc85d..dbee39902 100644
--- a/src/lib/content_store.h
+++ b/src/lib/show_playlist_content_store.h
@@ -27,10 +27,10 @@
class Content;
/** @class ContentStore
* @brief Class to maintain details of what content we have available to play
*/
-class ContentStore
+class ShowPlaylistContentStore
{
public:
std::shared_ptr<Content> get_by_digest(std::string digest) const;
@@ -42,7 +42,7 @@ public:
*/
std::vector<std::pair<std::string, std::string>> update(std::function<bool()> pulse);
- static ContentStore* instance();
+ static ShowPlaylistContentStore* instance();
std::vector<std::shared_ptr<Content>> const& all() const {
return _content;
@@ -51,5 +51,5 @@ public:
private:
std::vector<std::shared_ptr<Content>> _content;
- static ContentStore* _instance;
+ static ShowPlaylistContentStore* _instance;
};
@@ -27,10 +27,10 @@
class Content;
-/** @class ContentStore
- * @brief Class to maintain details of what content we have available to play
+/** @class ShowPlaylistContentStore
+ * @brief Class to maintain details of content that can be included in show playlists
*/